==> hs-glade-0.12.1p2.tgz: lib/ghc/glade-0.12.1/register.sh <==
#!/bin/sh
echo 'name: glade
version: 0.12.1
id: glade-0.12.1-4d62c708b7c962722930aa5abd6e3e64

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the glade library.
description: This library allows to load externally stored user interfaces into
             programs. This allows alteration of the interface without recompilation
             of the program.
             .
             Note that this functionality is now provided in gtk directly
             (as of version 2.12 of the gtk+ C lib) by the
             Graphics.UI.Gtk.Builder module.
category: Graphics
author: Manuel M T Chakravarty, Duncan Coutts
pkgpath: devel/hs-glade
exposed: True
exposed-modules: Graphics.UI.Gtk.Glade
hidden-modules: Graphics.UI.Gtk.Glade.Types
trusted: False
import-dirs: /usr/local/lib/ghc/glade-0.12.1
library-dirs: /usr/local/lib/ghc/glade-0.12.1 /usr/local/lib
              /usr/X11R6/lib
hs-libraries: HSglade-0.12.1
extra-libraries: glade-2.0 gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0
                 Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes X11
                 Xext atk-1.0 cairo gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0 m
                 gobject-2.0 glib-2.0 intl freetype z fontconfig xml2
extra-ghci-libraries:
include-dirs: /usr/local/include/libglade-2.0
              /usr/local/include/gtk-2.0 /usr/local/lib/gtk-2.0/include
              /usr/local/include/pango-1.0 /usr/local/include/gio-unix-2.0/
              /usr/X11R6/include /usr/local/include/cairo
              /usr/local/include/atk-1.0 /usr/X11R6/include/pixman-1
              /usr/local/include/libpng16 /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/harfbuzz /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/local/include
              /usr/X11R6/include/freetype2 /usr/local/include/libxml2
includes:
depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
         glib-0.12.4-e3c24025d434894ff47dcfccf269abe4
         gtk-0.12.4-5d2f81967dc5a43129cb5b717a39d4ea
hugs-options:
cc-options:
ld-options: "-Wl,-rpath-link,/usr/X11R6/lib"
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-glade-0.12.1/html/glade.haddock
haddock-html: /usr/local/share/doc/hs-glade-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-glade-0.12.5.0.tgz: lib/ghc/glade-0.12.5.0/register.sh <==
#!/bin/sh
export PATH='/usr/obj/hs-glade-0.12.5.0/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: glade
version: 0.12.5.0
id: glade-0.12.5.0-44097df3dcbe54b24845af8eea15ab53

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the glade library.
description: This library allows to load externally stored user interfaces into
             programs. This allows alteration of the interface without recompilation
             of the program.
             .
             Note that this functionality is now provided in gtk directly
             (as of version 2.12 of the gtk+ C lib) by the
             Graphics.UI.Gtk.Builder module.
category: Graphics
author: Manuel M T Chakravarty, Duncan Coutts
pkgpath: devel/hs-glade
exposed: True
exposed-modules: Graphics.UI.Gtk.Glade
hidden-modules: Graphics.UI.Gtk.Glade.Types
trusted: False
import-dirs: /usr/local/lib/ghc/glade-0.12.5.0
library-dirs: /usr/local/lib/ghc/glade-0.12.5.0 /usr/local/lib
              /usr/X11R6/lib
hs-libraries: HSglade-0.12.5.0
extra-libraries: glade-2.0 gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0
                 Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes X11
                 Xext atk-1.0 cairo gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0 m
                 gobject-2.0 glib-2.0 intl fontconfig freetype z xml2
extra-ghci-libraries:
include-dirs: /usr/local/include/libglade-2.0
              /usr/local/include/gtk-2.0 /usr/local/lib/gtk-2.0/include
              /usr/local/include/pango-1.0 /usr/local/include/gio-unix-2.0/
              /usr/X11R6/include /usr/local/include/cairo
              /usr/local/include/atk-1.0 /usr/X11R6/include/pixman-1
              /usr/local/include/libpng16 /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/harfbuzz /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/local/include
              /usr/X11R6/include/freetype2 /usr/include
              /usr/local/include/libxml2
includes:
depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         glib-0.12.5.4-d17f895d256b06ee8202922370af528b
         gtk-0.12.5.7-e67035cea6a2d971d3cb62d203d12660
hugs-options:
cc-options:
ld-options: "-Wl,-rpath-link,/usr/X11R6/lib"
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-glade-0.12.5.0/html/glade.haddock
haddock-html: /usr/local/share/doc/hs-glade-0.12.5.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
